@@ -86,7 +86,7 @@ def tmpl_new():
 @click.option(
     '--root', '-r', 'root',
     help='Root path, by default uses working directory',
-    default=None, type=str
+    default='', type=str
 )
 @click.option(
     '--extension', '-e', 'ext',
@@ -182,6 +182,21 @@ def gen(
     '-s', '--surface', 'surface_color',
     default='#343434', type=str
 )
+@click.option(
+    '-la', '--light-accent', 'light_accent_color',
+    help='Light Accent color',
+    default='#b26bc4', type=str
+)
+@click.option(
+    '-lb', '--light-background', 'light_background_color',
+    help='Light Background color',
+    default='#cacaca', type=str
+)
+@click.option(
+    '-ls', '--light-surface', 'light_surface_color',
+    help='Light Surface color',
+    default='#dedede', type=str
+)
 def serve(
         host: str,
         port: str,
@@ -191,13 +206,15 @@ def serve(
         accent_color: str,
         background_color: str,
         surface_color: str,
+        light_accent_color: str,
+        light_background_color: str,
+        light_surface_color: str,
 ):
     """
     The `serve` command starts a web server using FastAPI and uvicorn and
     provides access to Markdown files in a web browser.
     """
     user_template = get_user_template_path(templates_folder)
-    print(user_template)
     env = Environment(
         loader=FileSystemLoader(user_template if user_template else templates_folder),
         autoescape=select_autoescape()
@@ -232,6 +249,9 @@ def serve(
                     accentColor=accent_color,
                     backgroundColor=background_color,
                     surfaceColor=surface_color,
+                    lightAccentColor=light_accent_color,
+                    lightBackgroundColor=light_background_color,
+                    lightSurfaceColor=light_surface_color,
                     selected=f'/{doc}'
                 )
             )
@@ -289,6 +309,21 @@ def serve(
     help='Surface color',
     default='#343434', type=str
 )
+@click.option(
+    '-la', '--light-accent', 'light_accent_color',
+    help='Light Accent color',
+    default='#b26bc4', type=str
+)
+@click.option(
+    '-lb', '--light-background', 'light_background_color',
+    help='Light Background color',
+    default='#dfdfdf', type=str
+)
+@click.option(
+    '-ls', '--light-surface', 'light_surface_color',
+    help='Light Surface color',
+    default='#cacaca', type=str
+)
 @click.option(
     '-r', '--root', 'root',
     help='Root path, by default uses working directory',
@@ -301,6 +336,9 @@ def build(
         accent_color: str,
         background_color: str,
         surface_color: str,
+        light_accent_color: str,
+        light_background_color: str,
+        light_surface_color: str,
         document_type: str,
         ignore: str,
         extend: str,
@@ -319,13 +357,12 @@ def build(
     generate_md_files(docs, document_type, ignore, extend, output)
     if root is None:
         root = path.join(getcwd(), output, docs)
-    print(root)
 
+    if path.isfile(docs):
+        docs, filename = path.split(docs)
     docs = path.join(output, docs)
     sidebar, md_files = cast_md_dir_to_json(docs, root, True, '.html')
-    pprint(sidebar)
     md_files = [path.join(docs, i[1:]) for i in md_files]
-    print(md_files)
 
     for filename in md_files:
         with open(filename, 'r', encoding='utf-8') as file:
@@ -353,6 +390,9 @@ def build(
                     accentColor=accent_color,
                     backgroundColor=background_color,
                     surfaceColor=surface_color,
+                    lightAccentColor=light_accent_color,
+                    lightBackgroundColor=light_background_color,
+                    lightSurfaceColor=light_surface_color,
                     selected=f'{root}{filename[:-len(extension)]}.html'.replace('\\', '/')
                 )
             )
